#!/bin/bash
# Copyright (C) 2011 Generalitat de Catalunya 
# 
# This file is part of Linkat Tumbleweed.  
# 
# Linkat Tumbleweed is free software; you can redistribute it and/or modify it under
# the terms of the GNU General Public License as published by the Free
# Software Foundation; either version 3 of the License, or (at your option) any
# later version.
# 
# Linkat Tumbleweed is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
# FOR A PARTICULAR PURPOSE. See the GNU General Public License for further
# details, currently published at http://www.gnu.org/licenses/gpl.txt or in the
# gpl.txt in the ["legal" folder] of this distribution.
# 
# You should have received a copy of the GNU General Public License along with
# this program; If not, see <http://www.gnu.org/licenses/>
# 
# Authors: Jordi "Txor" Casas Ríos (jcasas@opentrends.net), openTrends Solucions i Sistemes, S.L.
# 
# You may contact the copyright holder at: linkat@xtec.cat
# 

#
# This library is a set of common used functions and variables.
#

#
# Variables and binary paths
ZENITY=`which zenity 2> /dev/null`
REBOOT=`which reboot 2> /dev/null`
ONECLICKUI=`which OneClickInstallUI 2> /dev/null`

#
# Functions

# Shows a dialog asking for reboot the system
prompt_reboot()
{
	if [ $ZENITY -a -x $ZENITY ] ; then
		# Using zenity
		$ZENITY --title="Reinici" --question --text="Es necessita reiniciar el sistema, voleu reiniciar ara?" --ok-label="Sí, reinicia." --cancel-label="No, ja reiniciaré jo."
		if [ $? -eq 0 ] ; then
			# Launching reboot
			launch_reboot
		fi
	else
		# Using command line
		RESPONSE=""
		while [[ $RESPONSE != "n" && $RESPONSE != "y" ]]
		do 
			echo "QUESTION: Es necessita reiniciar el sistema, voleu reiniciar ara? (y/n)"
			read RESPONSE
		done
		case $RESPONSE in
			y)	echo "INFO: Reiniciant el sistema..."
				launch_reboot;;
			n)	echo "INFO: Recordeu que cal reiniciar el sistema." ;;
		esac
	fi
}

# Launch reboot
launch_reboot()
{
			if [ $REBOOT -a -x $REBOOT ] ; then
				$REBOOT
			else
				echo "ERROR: Can't $REBOOT, not a command!"
			fi
}

# Spawn info
spawn_info()
{
	if [ $ZENITY -a -x $ZENITY ] ; then
		# Using zenity
		$ZENITY --title="$1" --info --text="$2"
	else
		# Using command line
		echo "INFO: $1"
		echo "INFO: $2"
		echo "(Press ENTER to continue...)"
		RESPONSE=""
		while [[ $RESPONSE == "" ]]
		do 
			read RESPONSE
		done
	fi
}

# Check that we are root and exit otherwise.
check_we_are_root()
{
	if [ `id -u` -ne 0 ] ; then
		echo "ERROR: We are $USER! (not root)"
		exit 1
	fi
}

# Check for packagekitd existance and kill it!
check_kill_packagekit()
{
	PKGKIT_PID=`ps ax | grep packagekitd | grep -v grep | cut -f 1 -d " "`
	if [ $PKGKIT_PID ] ; then 
		kill -9 $PKGKIT_PID 
		echo "INFO: packagekitd killed with $PKGKIT_PID PID!"
	fi
}
